@@ -5,11 +5,10 @@ from zope.interface import implementer
 
 @implementer(INonInstallable)
 class HiddenProfiles(object):
-
     def getNonInstallableProfiles(self):
         """Hide uninstall profile from site-creation and quickinstaller."""
         return [
-            'library.core:uninstall',
+            "library.core:uninstall",
         ]
 
 
